#!/usr/bin/perl -w
#
# Part of TUI-SH
# (c) 2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://fs.fsf.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: html2text.pl,v 1.2 2002/08/05 06:57:22 yeupou Exp $
#

#################
# configuration

use strict;
use Getopt::Long;

use HTML::Entities qw(decode_entities);

use File::Basename;

use Text::Wrap;

use LWP::UserAgent;
use HTTP::Request;
use HTTP::Response;
use URI::Heuristic;

# general
my $TUISH_AUTHOR="2002 Mathieu Roy";
my $TUISH_MAIL="tui-sh-dev\@mail.freesoftware.fsf.org";
my $x; ### UGLY To be able to have CVS date
my $TUISH_VER="\$Date: 2002/08/05 06:57:22 $x";

my $getopt;
my $help;
my $version;
my $get;
my $wget;

#############
# here we go
# get options
eval {
    $getopt = GetOptions("help" => \$help,
			 "version" => \$version,
			 "get" => \$get,
			 "wget" => \$wget);
};

# def return
if($help) {
    print STDERR <<EOF;
Usage: $0 [OPTION] file or url
Convert a HTML file to text (STDOUT).
Inspired by O\'Reilly\'s "Perl en action".

  -h, --help                 display this help and exit
      --version              output version information and exit
  -g, --get                  get file on the web
  -w, --wget                 download file with wget

Report bugs or suggestions to <$TUISH_MAIL>
EOF
exit(1);
}

if($version) {
    print STDERR <<EOF;
$0 - $TUISH_VER

Copyright (c) $TUISH_AUTHOR <$TUISH_MAIL>
This is free software; see the source for copying conditions.
There is NO warranty; not even for MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.
EOF
exit(1);
}

my $file = basename(@ARGV);

if ($wget) {
    `wget @ARGV`;
}
if ($get) {
    printf "%s =>\n\t", @ARGV;
    my $ua = LWP::UserAgent->new();
    $ua->agent("html2text/chaos");
    my $req = HTTP::Request->new(GET => @ARGV);
    $req->referer("http://a.la.bastoche.bah");
    my $answer = $ua->request($req);
    if($answer->is_error()) {
	printf " %s\n", $answer->status_line;
    } else {
	my $count;
	my $bytes;
	my $content = $answer->content();
	$bytes = length $content;
	$count = ($content =~ tr/\n/\n/);
	printf "%s (%d lines, %d bytes)\n\n", $answer->title(), $count, $bytes;
	open(FILEIN, "> $file") or die "Cannot open $file for writing";
	print FILEIN $content;
	close(FILEIN);
    }
}

$Text::Wrap::columns = 75;
open(FILEIN, "< $file") or die "Cannot open $file for reading";

while (<FILEIN>) {
    s/<[^>]*>//gs;
    print STDOUT wrap(" " x 3, "", decode_entities($_));
}

close(FILEIN);
 

# END
