#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://fs.fsf.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: latex2ps.sh,v 1.2 2002/08/05 06:54:09 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"

TUISH_NAME="latex2ps"
TUISH_VER="\$Date: 2002/08/05 06:54:09 $"
TUISH_DESC="Convert a LaTeX formatted file to a postscript file - eventually to a pdf file."
TUISH_USAGE="[OPTION] file[.tex]"
TUISH_REQUIRE="latex, dvips, ps2pdf"
TUISH_HELP_00="  -p, --print                print the output directly"
TUISH_HELP_01="  -v, --view                 show the output with gv (or ggv if available)"
TUISH_HELP_02="      --pdf                  generate also a pdf output"
TUISH_HELP_03="      --pdf-only             generate only a pdf output"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# some var
unset PRINT VIEW PDF OPDF

#################
# functions
function TUISH_ltxps_compile {
    if [ ! -e "$FILE".tex ] ; then
	TUISH_help
	exit
    fi
    # we latex-compile 2 times so we get nice \tableofcontents
    latex \\nonstopmode\\input "$FILE".tex
    latex \\nonstopmode\\input "$FILE".tex
    dvips -o "$FILE".ps "$FILE".dvi
    rm -f "$FILE".aux "$FILE".log "$FILE"*~ "$FILE".dvi

}

function TUISH_ltxps_compile_pdf {
    ps2pdf "$FILE".ps
}

function TUISH_ltxps_compile_pdf_only {
    rm -f "$FILE".ps
}

function TUISH_ltxps_view {
    GGV=`which ggv`
    GV=`which gv`
    if [ ! -e "$FILE".ps ] ; then
	echo -e "\\033[1;31m""No postscript ouput available.""\\033[0;39m"
	exit
    fi    
    if [ -x "$GGV" ] ; then
	ggv "$FILE".ps &
    elif [ -x "$GV" ] ; then
	gv -watch "$FILE".ps &
    else
	echo " "
	echo -e "\\033[1;31m""Neither ggv or gv seems available.""\\033[0;39m"
	echo "Maybe there are not in the \$PATH."
    fi
}

function TUISH_ltxps_print {
    lpr < "$FILE".ps
}


#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hpv --long help,version,print,view,pdf,pdf-only \
     -n $TUISH_NAME -- "$@"`
eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	-p|--print) PRINT=1 ; shift ;;
	-v|--view) VIEW=1 ; shift ;;
	--pdf) PDF=1; shift ;;
	--pdf-only) OPDF=1  ; shift ;;
	*) break ;;
    esac
done

# what file it is: it should be the last remaining arg from getopt
for arg do FILE="$arg"; done
# we remove it's extension, we dont want it
FILE="`echo $arg | sed s/.tex//g`"
# if no input file exists, show help and exit
if [ ! -e "$FILE".tex ] ; then
    	echo -e "\\033[1;31m""No LaTeX input available or specified.""\\033[0;39m"
	TUISH_help
	exit
fi
# do what user want
TUISH_ltxps_compile 
if [ $PRINT ] ; then TUISH_ltxps_print ; fi
if [ $VIEW ] ; then TUISH_ltxps_view ; fi
if [ $PDF ] ; then TUISH_ltxps_compile_pdf ; fi
if [ $OPDF ] ; then TUISH_ltxps_compile_pdf_only ; fi

#############
# end
