#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: mkthumb.sh,v 1.3 2002/07/17 07:06:52 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"


TUISH_NAME="mkthumb"
TUISH_VER="\$Date: 2002/07/17 07:06:52 $"
TUISH_DESC="Create a thumbnail (small picture) of a picture. Currently it use feh, but the future version will use ImageMagick"
TUISH_USAGE="[OPTION] input_file"
TUISH_REQUIRE="feh, ImageMagick"

TUISH_HELP_00=" "
TUISH_HELP_01="General options:"
TUISH_HELP_02="  -f, --force                overwrite old thumbs"
TUISH_HELP_03="  -o file, --output file     give a filename for the output"
TUISH_HELP_04="  -h size, --height size     height size (default 100)"
TUISH_HELP_05="  -w size, --width size      width size (default 150)"
TUISH_HELP_06=" "
TUISH_HELP_07="Image Magick options:"
TUISH_HELP_08="      --antialias            remove pixel aliasing"
TUISH_HELP_09="      --background color     background color"
TUISH_HELP_10="      --blur                 blur the image"
TUISH_HELP_11="      --comment string       annotate image with comment"
TUISH_HELP_12="      --roll geometry        roll an image vertically or horizontally"
TUISH_HELP_13="      --rotate degrees       apply Paeth rotation to the image"
TUISH_HELP_14=" "
TUISH_HELP_15="EXAMPLE: $TUISH_NAME my_pic.jpg -o little_my_pic.png -f -h 150 --width 125 --antialias"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# vars
unset FORCE IMG_OUT ANTIALIAS BACKGROUND BLUR COMMENT ROLL ROTATE
HEIGHT=100
WIDTH=150

#################
# functions

# Only one action, no need to use functions

#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o fo:h:w: --long force,help,output:,height:,width:,antialias,background:,blur,comment:,roll:,rotate: \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	-f|--force) FORCE=1 ; shift ;;
	-o|--output) IMG_OUT="$2" ; shift 2 ;;
	-h|--height) HEIGHT="$2" ; shift 2 ;;
	-w|--width) WIDTH="$2" ; shift 2 ;;
	--antialias) ANTIALIAS=1 ; shift ;;
	--background) BACKGROUND=1 && BACKGROUND_DATA="$2" ; shift ;;
	--blur) BLUR=1 ; shift ;;
	--comment) COMMENT=1 && COMMENT_DATA="$2" ; shift ;;
	--roll) ROLL=1 && ROLL_DATA="$2" ; shift ;;
	--rotate) ROTATE=1 && ROTATE_DATA="$2" ; break ;;
	*) break ;;
    esac
done

# what file it is: it should be the last remaining arg from getopt
for arg do IMG_IN="$arg"; done
# if no input file exists, show help and exit
if [ ! -e "$IMG_IN" ] ; then
    echo -e "\\033[1;31m""No input available or specified.""\\033[0;39m"
    TUISH_help
    exit
fi
# what should be the output file
if [ ! "$IMG_OUT" ] ; then
   EXTENSION=`echo "$IMG_IN" | sed s/"\."/" "/g | awk '{ print $2 }'`
   IMG_OUT=`basename "$IMG_IN" .$EXTENSION`"_thumb.$EXTENSION"
fi 

# check if thumbnail dont exist already
if [ -e "$IMG_OUT" ] && [ ! $FORCE ] ; then	
    echo -e "\\033[1;31m""error : ""\\033[0;39m""sorry, there's already a thumb"
    echo "to replace it, use the option --force at the end of the command line"
    exit
fi
	
# create the thumb
LIMIT_HEIGHT=`expr "$HEIGHT" + 5`
LIMIT_WIDTH=`expr "$WIDTH" + 5`
#convert "$IMG_IN" "$IMG_OUT" 
feh "$IMG_IN" -b trans -m --limit-width $LIMIT_WIDTH --limit-height $LIMIT_HEIGHT --thumb-width $WITDH --thumb-height $HEIGHT -O $IMG_OUT
echo "$IMG_IN -> $IMG_OUT ($HEIGHT x $WIDTH)"



#############
# end