#!/usr/bin/perl -w
#
# Part of TUI-SH
# (c) 2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://fs.fsf.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: text2html.pl,v 1.2 2002/08/05 06:57:22 yeupou Exp $
#

#################
# configuration

use strict;
use Getopt::Long;
use HTML::Entities;

# general
my $TUISH_AUTHOR="2002 Mathieu Roy";
my $TUISH_MAIL="tui-sh-dev\@mail.freesoftware.fsf.org";
my $x; ### Get CVS date
my $TUISH_VER="\$Date: 2002/08/05 06:57:22 $x";

my $getopt;
my $help;
my $version;


#############
# here we go
# get options
eval {
    $getopt = GetOptions("help" => \$help,
			 "version" => \$version);
};

# def return
if($help) {
    print STDERR <<EOF;
Usage: $0 [OPTION] file
Convert a text file to HTML (STDOUT).
Inspired by O\'Reilly\'s "Perl en action".

  -h, --help                 display this help and exit
      --version              output version information and exit

Report bugs or suggestions to <$TUISH_MAIL>
EOF
exit(1);
}

if($version) {
    print STDERR <<EOF;
$0 - $TUISH_VER

Copyright (c) $TUISH_AUTHOR <$TUISH_MAIL>
This is free software; see the source for copying conditions.
There is NO warranty; not even for MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.
EOF
exit(1);
}


open(FILE, "< @ARGV") or die "Cannot open @ARGV for reading";
while (<FILE>) {
    $_ = encode_entities($_, "\200-\377");
    s{^(>.*)}{$1<br>}gm;                   # quote text that begin with >
    s{<URL:(.*?)>}{<a href="$1">$1</a>}gs; # url
    s{\*(\S+)\*}{<b>$1</b>}g;              # *bold*
    s{\b_(\S+)\_\b}{<i>$1</i>}g;           # _italic_
    s{^}{<p>\n};
    print STDOUT $_;
}
close(FILE);
    
# END
