#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: tui-sh-installation-update.sh,v 1.4 2002/07/17 09:48:12 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"

TUISH_NAME="tui-sh-installation-update"
TUISH_VER="\$Date: 2002/07/17 09:48:12 $"
TUISH_DESC="Re-install your personal scripts + tui-sh ones edited by you"
TUISH_USAGE="[OPTION]"
TUISH_REQUIRE="make"
TUISH_HELP_00="  -c, --configure            create a .tuish-iurc configuration file"
TUISH_HELP_01="      --compat               make symlinks to simulate tui-sh < 1.0.5 compatibility"
TUISH_HELP_02="  -i, --install              install/update scripts (perso/tui-sh)"
TUISH_HELP_03="                             available on your box"
TUISH_HELP_04="  -l, --list                 list scripts shipped with TUI-SH"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# other information
RCFILE="$HOME/.tuish-iurc"

#################
# functions
function TUISH_iu_configuration {
    echo "Where are located TUI-SH scripts ?"
    echo "Ex : /opt/tui-sh"
    echo "(should be the same tree as the original provided by tui-sh)"
    read TUI_SH
    echo "TUI_SH=\"$TUI_SH\"" > $RCFILE
    echo "Where are located your own scripts ?"
    echo "(should all be in the same dir, with .pl or .sh suffix)"
    echo "Ex : /opt/my_scripts"
    read OWN_SH
    echo "OWN_SH=\"$OWN_SH\"" >> $RCFILE
    echo "Where should we install script, what prefixs ?"
    echo "($PREFIX/bin will be the scripts location)"
    echo "Ex : /usr/local"
    read PREFIX
    echo "PREFIX=\"$PREFIX\"" >> $RCFILE
}

function TUISH_iu_test_configuration {
    if [ ! -e "$RCFILE" ] ; then
	echo "No configuration file ($RCFILE)"
	TUISH_iu_configuration
    else
	. $RCFILE
    fi
}

function TUISH_iu_install {
    TUISH_iu_test_configuration
    cd "$TUI_SH" && ./configure --src="$TUI_SH" --prefix="$PREFIX" && make install
    cd "$OWN_SH" && for file in *.sh ; do install -v "$file" "$PREFIX/bin/`basename $file .sh`" ; done
    cd "$OWN_SH" && for file in *.pl ; do install -v "$file" "$PREFIX/bin/`basename $file .pl`" ; done
}

function TUISH_iu_show_list {
    echo "For each script, you can type script --help:"
    if [ -e /usr/lib/tui-sh/scripts_list ] ; then
	cat /usr/lib/tui-sh/scripts_list
    else
	echo "The scripts list can't be found"
	echo "Take a look at http://sv.gnu.org/projects/tui-sh"
    fi
}

function TUISH_iu_compat {
    ln -sf `which tui-sh-installation-update` /usr/local/bin/Si
    ln -sf `which urlize` /usr/local/bin/Surlize
    ln -sf `which latex2ps` /usr/local/bin/Stex
    ln -sf `which murder` /usr/local/bin/Skill
    ln -sf `which mkthumb` /usr/local/bin/Sthumbnail
    ln -sf `which initctl` /usr/local/bin/Sctl
    ln -sf `which ogg2wav` /usr/local/bin/Sogg2wav
    ln -sf `which mp32wav` /usr/local/bin/Smp32wav
    ln -sf `which wav2ogg` /usr/local/bin/Swav2ogg
    ln -sf `which euro2other` /usr/local/bin/Seuro
    ln -sf `which maj_ftp` /usr/local/bin/Smaj_ftp
    ln -sf `which maj_ftp` /usr/local/bin/Smaj_lftp
}



#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hluvc --long help,list,install,version,configure,compat \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	-c|--configure) TUISH_iu_configuration ; break ;;
	-i|--install) TUISH_iu_install ; break ;;
	-l|--list) TUISH_iu_show_list ; break ;;
	--compat) TUISH_iu_compat ; break ;;
	*) TUISH_help; break ;;
    esac
done

#############
# end
