#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: urlize.sh,v 1.1 2002/07/16 10:31:15 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"


TUISH_NAME="urlize"
TUISH_VER="\$Date: 2002/07/16 10:31:15 $"
TUISH_DESC="Rename files in a directory to a simplified name, (mainly for Universal Ressources Locators, URL)"
TUISH_USAGE="[OPTION]"
TUISH_REQUIRE="tr"
TUISH_HELP_00="  -d, --dir D                rename files in dir D (default)"
TUISH_HELP_01="  -e, --expression E         urlize expression E"
TUISH_HELP_02=" "
TUISH_HELP_03="EXAMPLE: $TUISH_NAME .    # would urlize each file in the current dir"
TUISH_HELP_04="         $TUISH_NAME -d . # same command"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

#################
# functions

function TUISH_urlize_dir {
    cd "$D"
    for i in * ; do
	PROPRE=`echo $i | tr " " "_" | tr "-" "a-e" | tr "+" "_" | tr "=" "_" | tr "" "u" | sed s/"'"/""/g | sed s/"%"//g`
	if [ "$PROPRE" != "$i" ] ; then
	    mv -v "$i" "$PROPRE"
	else 
	    echo "\`$i' = \`$PROPRE'"
	fi
    done
}
    
function TUISH_urlize_expression {
    echo "$E" | tr " " "_" | tr "-" "a-e" | tr "+" "_" | tr "=" "_" | tr "" "u" | sed s/"'"/""/g | sed s/"%"//g
}

#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hve:d: --long help,version,dir:,expression: \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	-e|--expression) E="$2" && TUISH_urlize_expression ; break ;;
	-d|--dir) D="$2" && TUISH_urlize_dir ; break ;;
	*) TUISH_help ; break ;;
    esac
done

#############
# end