#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: euro2other.sh,v 1.2 2002/07/17 09:39:26 yeupou Exp $
#

#################
# configuration

# VARS: euros currencies: 1 EUR
unset EUR STRICT CURRENCY

BEFC="Belgium"
BEF="40.3399"

DEMC="Germany"
DEM="1.95583"

ESPC="Spain"
ESP="166.386"

FRFC="France"
FRF="6.55957"

IEPC="Ireland"
IEP="0.787564"

ITLC="Italy"
ITL="1936.27"

LUFC="Luxembourg"
LUF="40.3399"

NLGC="Netherlands"
NLG="2.20371"

ATSC="Austria"
ATS="13.7603"

PTEC="Portugal"
PTE="200.482"

FIMC="Finland"
FIM="5.94573"

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"


TUISH_NAME="euro2other"
TUISH_VER="\$Date: 2002/07/17 09:39:26 $"
TUISH_DESC="Conversion euro <-> others old europeans currencies."
TUISH_USAGE="[OPTION] value"
TUISH_REQUIRE="perl"
TUISH_HELP_00=" "
TUISH_HELP_01="  -s, --strict               result not rounded"
TUISH_HELP_02="  -o, --only                 output _only_ the numerical result"
TUISH_HELP_03="      --eur                  input value is EUR (euro)"
TUISH_HELP_04=" "
TUISH_HELP_05="      --bef                  input value is BEF ($BEFC)"
TUISH_HELP_06="      --dem                  input value is DEM ($DEMC)"
TUISH_HELP_07="      --esp                  input value is ESP ($ESPC)"
TUISH_HELP_08="      --frf                  input value is FRF ($FRFC)"
TUISH_HELP_09="      --iep                  input value is IEP ($IEPC)"
TUISH_HELP_10="      --itl                  input value is ITL ($ITLC)"
TUISH_HELP_11="      --luf                  input value is LUF ($LUFC)"
TUISH_HELP_12="      --nlg                  input value is NLG ($NLGC)"
TUISH_HELP_13="      --ats                  input value is ATS ($ATSC)"
TUISH_HELP_14="      --pte                  input value is PTE ($PTEC)"
TUISH_HELP_15="      --fim                  input value is FIM ($FIMC)"
TUISH_HELP_16=" "
TUISH_HELP_17="EXAMPLE:"
TUISH_HELP_18="  $TUISH_NAME --eur 1           # would produce a conversion table"
TUISH_HELP_19="                               # for euro"
TUISH_HELP_20="  $TUISH_NAME --frf 15          # would convert 15 FRF to euro"
TUISH_HELP_21="  $TUISH_NAME 15 --pte          # would convert 15 PTE to euro"
TUISH_HELP_22="  $TUISH_NAME 15 --eur --frf    # would convert 15 euro to FRF"
TUISH_HELP_23="  $TUISH_NAME --eur --pte 15    # would convert 15 euro to PTE"
TUISH_HELP_24="  $TUISH_NAME 15                # would producte a conversion table"
TUISH_HELP_25="                               # for 15 euro"
# Source function library.
. /usr/lib/tui-sh/libinfo.5

#################
# functions

function TUISH_euro_convert {
    if [ ! $EUR ] ; then
	TUISH_euro_other_to_euro
    else 
	TUISH_euro_euro_to_other
    fi	
    if [ ! $STRICT ] ; then
	TUISH_euro_round_result
    fi
    TUISH_euro_show_result
}

function TUISH_euro_other_to_euro {
    RESULT=`perl -e "print $VALUE/$CURRENCY"`

}

function TUISH_euro_euro_to_other {
    RESULT=`perl -e "print $VALUE*$CURRENCY"`

}

function TUISH_euro_round_result {
    RESULT=`perl -e "print sprintf(\"%.2f\", $RESULT)"`
}

function TUISH_euro_show_result {
    if [ ! $ONLY ] ; then
	if [ ! $EUR ] ; then
	    INPUT="$VALUE $CURRENCY_TYPE"
	    OUTPUT="$RESULT EUR"
	else
	    INPUT="$VALUE EUR"
	    OUTPUT="$RESULT $CURRENCY_TYPE"
	fi
	echo "$INPUT           = $OUTPUT"
    else
	echo "$RESULT"
    fi
}



#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hvso --long help,version,strict,only,eur,bef,dem,esp,frf,iep,itl,luf,nlg,ats,pte,fim \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	--eur) EUR=1 ; shift ;;
	--strict|-s) STRICT=1 ; shift ;;
	--only|-o) ONLY=1 ; shift ;;
	--bef) CURRENCY=$BEF && CURRENCY_TYPE=BEF ; shift ;;
	--dem) CURRENCY=$DEM && CURRENCY_TYPE=DEM ; shift ;;
	--esp) CURRENCY=$ESP && CURRENCY_TYPE=ESP ; shift ;;
	--frf) CURRENCY=$FRF && CURRENCY_TYPE=FRF ; shift ;;
	--iep) CURRENCY=$IEP && CURRENCY_TYPE=IEP ; shift ;;
	--itl) CURRENCY=$ITL && CURRENCY_TYPE=ITL ; shift ;;
	--luf) CURRENCY=$LUF && CURRENCY_TYPE=LUF ; shift ;;
	--ngl) CURRENCY=$NLG && CURRENCY_TYPE=NGL ; shift ;;
	--ats) CURRENCY=$ATS && CURRENCY_TYPE=ATS ; shift ;;
	--pte) CURRENCY=$PTE && CURRENCY_TYPE=PTE ; shift ;;
	--fim) CURRENCY=$FIM && CURRENCY_TYPE=FIM ; shift ;;
#	--*) CURRENCY=`echo $1 | sed s/"--"//g` ; break ;;
	*) break ;;
    esac
done

# what value it is: it should be the last remaining arg from getopt
for arg do VALUE="$arg"; done
if [ "$VALUE" == "--" ] ; then
    echo "$TUISH_NAME: error: you must specify a value to convert"
    exit
fi

if [ $CURRENCY ] ; then
    TUISH_euro_convert
else
    EUR=1
    CURRENCY=$BEF && CURRENCY_TYPE=BEF
    TUISH_euro_convert
    CURRENCY=$DEM && CURRENCY_TYPE=DEM
    TUISH_euro_convert
    CURRENCY=$ESP && CURRENCY_TYPE=ESP
    TUISH_euro_convert
    CURRENCY=$FRF && CURRENCY_TYPE=FRF
    TUISH_euro_convert
    CURRENCY=$IEP && CURRENCY_TYPE=IEP
    TUISH_euro_convert
    CURRENCY=$ITL && CURRENCY_TYPE=ITL
    TUISH_euro_convert
    CURRENCY=$LUF && CURRENCY_TYPE=LUF
    TUISH_euro_convert
    CURRENCY=$NLG && CURRENCY_TYPE=NGL
    TUISH_euro_convert
    CURRENCY=$ATS && CURRENCY_TYPE=ATS
    TUISH_euro_convert
    CURRENCY=$PTE && CURRENCY_TYPE=PTE
    TUISH_euro_convert
    CURRENCY=$FIM && CURRENCY_TYPE=FIM   
    TUISH_euro_convert 
fi

#############
# end