#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: initctl.sh,v 1.3 2002/07/25 09:39:35 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"

# Script dtails
TUISH_NAME="initctl"
TUISH_VER="\$Date: 2002/07/25 09:39:35 $"
TUISH_DESC="Shortcut to init.d sysv scripts"
TUISH_USAGE="daemon action"
TUISH_HELP_00="action can be start|s, stop|halt|h, restart|r, status"
TUISH_HELP_01="EXAMPLE: $TUISH_NAME exim start"
TUISH_HELP_02="      or $TUISH_NAME exim s"
TUISH_HELP_03="      will start the httpd daemon"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# var 
INITD=/etc/init.d
unset DAEMON START STOP STATUS RESTART

#################
# functions

 # no functions #

#############
# here we go

# we test if the daemon specified really exists
if [ $1 ] ; then
    if [ -e $INITD/$1 ] ; then
	DAEMON=$1
    elif [ $1 == "--help" ] || [ $1 == "-h" ] ; then
	TUISH_help
    elif [ $1 == "--version" ] ; then
	TUISH_version
    fi
fi

# if no daemon is known, well, it's just like
# if the script was start without option.
# in this case, we ask the user to choose a daemon
# in the list of existing daemons
if [ ! $DAEMON ] ; then
    echo "No daemon was specified in the command line"
    echo "Please, choose one of the following:"
    ls --color=no $INITD
    echo -n "Daemon concerned: "
    read DAEMON
    if [ ! -e $INITD/$DAEMON ] ; then
	echo "$TUISH_NAME: $INITD/$DAEMON: no such daemon"
	exit
    fi
    
fi

# if the user specified an action, set flags
if [ $2 ] ; then
    case "$2" in
	-h|--help) TUISH_help ;;
	--version) TUISH_version ;;
	s|start) START=1 ;;
	r|restart) RESTART=1 ;;
	h|stop|halt) STOP=1 ;;
	status) STATUS=1 ;;
	*) ACTION_UNDEF=1 ;;
    esac
else
    ACTION_UNDEF=1 
fi
    
# if no action is known, we ask the user to choose one
if [ $ACTION_UNDEF ] ; then
    echo "No action was specified in the command line"
    echo "Please, choose one of the following:"
    echo "  s|start"
    echo "  h|halt|stop"
    echo "  r|restart"
    echo "  status"
    echo -n "Action to perform: "
    read ACTION
    case $ACTION in 
	s|start) START=1 ;;
	r|restart) RESTART=1 ;;
	h|stop|halt) STOP=1 ;;
	status) STATUS=1 ;;
	*) echo "$TUISH_NAME: $ACTION: ignored command" && exit ;;
    esac
fi

# now every informations we may want should be found
if [ $RESTART ] ; then su -c "$INITD/$DAEMON restart" ; fi
if [ $STOP ] ; then su -c "$INITD/$DAEMON stop" ; fi
if [ $START ] ; then su -c "$INITD/$DAEMON start" ; fi
if [ $STATUS ] ; then su -c "$INITD/$DAEMON status" ; fi


#############
# end