#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: ogg2wav.sh,v 1.2 2002/07/25 09:39:35 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"


TUISH_NAME="ogg2wav"
TUISH_VER="\$Date: 2002/07/25 09:39:35 $"
TUISH_DESC="Convert each ogg [or mp3] files in a dir to wav."
TUISH_USAGE="[OPTION]"
TUISH_REQUIRE="df, ogg123, [mpg321]"
TUISH_HELP_00="  -s, --strict               only convert files with a correct suffix"
TUISH_HELP_01="                             (.ogg, .mp3)"
TUISH_HELP_02="      --ogg PATH             ogg files directory's path (default pwd)"
TUISH_HELP_03="      --wav PATH             wav files directory's path (default pwd/wav)"
TUISH_HELP_04="      --mp3                  files are mp3, not ogg"
TUISH_HELP_05="      --mp3-info             show info about mp3 and exit"
TUISH_HELP_06="  -f, --force                doesn't prompt the user to acknowledge options"         
TUISH_HELP_07="WARNING: all files in the specified directory will be converted"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# vars
TYPE=ogg
NAME_POLICY=nevermind
OGG=`pwd`
WAV=$OGG/wav
unset FORCE

#################
# functions


function TUISH_oggwav_show_option {
    echo "Configuration for this session:"
    echo "  checking file name policy... $NAME_POLICY"
    echo "  checking input file type... $TYPE"
    echo "  $TYPE files should be in $OGG"
    echo "  wav files will be written in $WAV"
    echo " "
    if [ ! $FORCE ] ; then
	echo "If that's ok, type enter (otherwise, type CTRL-C)"
	read void
    fi
}

function TUISH_oggwav_mp3_infos {
    if [ "$TYPE" == "mp3" ] ; then
	echo " "
	echo -e "\\033[1;31m""Are you aware that mp3 is not really *free* ?""\\033[0;39m"
	echo "You should take a look at :"
	echo "  http://www.mp3licensing.com"
	echo "  http://www.mp3licensing.com/royalty"
	echo "  http://www.transnationale.org/fiches/-1686450519.htm (fr)"
        echo " "
	sleep 3s
    fi
}

function TUISH_oggwav_convert {
    cd "$OGG"
    if [ ! -e "$WAV" ] ; then
	mkdir -pv "$WAV"
    fi
    if [ $NAME_POLICY == "strict" ] ; then
	in=*.$TYPE
    else
	in=*
    fi
    for file in $in ; do
	df
	if [ "$TYPE" == "ogg" ] ; then
	    ogg123 -v -d wav -f "$WAV/$file.wav" "$file"
	elif [ "$TYPE" == "mp3" ] ; then
	    mpg321 --wav "$WAV/$file.wav" "$file"
	else 
	    echo "$TUISH_NAME: unable to identify file type"
	    exit
	fi
    done
}
    



#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hvsf --long help,version,strict,ogg:,wav:,mp3,mp3-info,force \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	--mp3-info) TYPE=mp3 && TUISH_oggwav_mp3_infos && exit ; break ;;
	-s|--strict) NAME_POLICY=strict ; shift ;;
	--mp3) TYPE=mp3 ; shift ;;
	--ogg) OGG="$2" ; shift 2 ;;
	--wav) WAV="$2" ; shift 2 ;;
	-f|--force) FORCE=1 ; break ;;
	*) break ;;
    esac
done

TUISH_oggwav_show_option
TUISH_oggwav_mp3_infos
TUISH_oggwav_convert

#############
# end