#!/bin/sh
#
# Part of TUI-SH
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
#  see http://sv.gnu.org/projects/tui-sh
#  comments to <tui-sh-dev@mail.freesoftware.fsf.org>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: wav2ogg.sh,v 1.1 2002/07/17 07:06:53 yeupou Exp $
#

#################
# configuration

# general
TUISH_AUTHOR="2001-2002 Mathieu Roy"
TUISH_MAIL="tui-sh-dev@mail.freesoftware.fsf.org"


TUISH_NAME="wav2ogg"
TUISH_VER="\$Date: 2002/07/17 07:06:53 $"
TUISH_DESC="Convert each wav files in a dir to ogg."
TUISH_USAGE="[OPTION] --band band_name"
TUISH_REQUIRE="df, oggenc, urlize, tr"
TUISH_HELP_00="  -s, --strict               only convert files with a correct suffix"
TUISH_HELP_01="                             (.wav)"
TUISH_HELP_02="      --ogg PATH             ogg files directory's path (default pwd/ogg)"
TUISH_HELP_03="      --wav PATH             wav files directory's path (default pwd)"
TUISH_HELP_04="      --band band_name       band name (required)"
TUISH_HELP_05="      --album album_name     album name"
TUISH_HELP_06="      --comment comment      encoding comment"
TUISH_HELP_07="  -r, --remove               remove wav files once converted"
TUISH_HELP_08="  -f, --force                doesn't prompt the user to acknowledge options"
TUISH_HELP_09=" "
TUISH_HELP_10="WARNING: all files in the specified directory will be converted"
TUISH_HELP_11="         file names will be interpreted as songs name"

# Source function library.
. /usr/lib/tui-sh/libinfo.5

# vars
TYPE=ogg
NAME_POLICY=nevermind
REMOVE=nothing
WAV=`pwd`
OGG=$WAV/ogg
unset FORCE

#################
# functions


function TUISH_wavogg_show_option {
    echo "Configuration for this session:"
    echo "  checking file name policy... $NAME_POLICY"
    echo "  checking what should be done of $TYPE after the conversion... $REMOVE"
    echo "  $TYPE files should be in $OGG"
    echo "  wav files will be written in $WAV"
    echo "  band name is $BAND"
    echo "  album name is $ALBUM"
    echo "  comment content is $COMMENT"
    echo " "
    if [ ! $FORCE ] ; then
	echo "If that's ok, type enter (otherwise, type CTRL-C)"
	read void
    fi
}

function TUISH_wavogg_convert {
    cd "$WAV"
    if [ ! -e "$OGG" ] ; then
	mkdir -pv "$OGG"
    fi
    if [ $NAME_POLICY == "strict" ] ; then
	in=*.$TYPE
    else
	in=*
    fi
    for file in $in ; do
	df
	FILENAME=`echo "$BAND" | tr a-z A-Z`"-$file.$TYPE"
	FILENAME=`urlize -e "$FILENAME"`
	if [ "$ALBUM" ] ; then
	    ENC_OPTION="--album $ALBUM"
	fi
	if [ "$COMMENT" ] ; then
	    ENC_OPTION="$ENC_OPTION --comment=$COMMENT"
	fi
	oggenc --output="$OGG/$FILENAME" --artist "$BAND" --title "$file" $ENC_OPTION "$file"
	if [ $REMOVE == trash ] ; then
	    rm -f "$file"
	fi
    done
}
    



#############
# here we go

# Get options
GETOPT_TEMP=`getopt -o hvsfr --long help,version,strict,ogg:,wav:,force,remove,band:,comment:,album: \
     -n $TUISH_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# set action
while true ; do
    case "$1" in
	-h|--help) TUISH_help ; break ;;
	--version) TUISH_version ; break ;;
	-s|--strict) NAME_POLICY=strict ; shift ;;
	-r|--remove) REMOVE=trash ; shift ;;
	-f|--force) FORCE=1 ; shift ;;
	--ogg) OGG="$2" ; shift 2 ;;
	--wav) WAV="$2" ; shift 2 ;;
	--band) BAND="$2" ; shift 2 ;;
	--album) ALBUM="$2" ; shift 2 ;;
	--comment) COMMENT="$2" ; break ;;
	*) break ;;
    esac
done

if [ ! $BAND ] ; then    
    echo "$TUISH_NAME: no band name specified"
    exit
fi


TUISH_wavogg_show_option
TUISH_wavogg_convert

#############
# end