#! /bin/sh
#
# adsl.sh - Easily manage your ADSL connection
#
# Copyright (c) 2000 Raphal HALIMI <raphaelh@easynet.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

if [ "$1" == "--help" ] ; then
echo "this script can be used to manage ADSL via pptp connection"
echo "this is a SysV script : usage start|stop|restart"
exit
fi

VERSION="2.2"

# Some variables... Don't change them. Believe me.
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
NAME=adsl
DESC="ADSL link"
TERM=linux
TAIL="tail -n 5 /var/log/messages"

# Temp files. Don't touch them.
TMP_DIR=/tmp/adsl.sh
LOCK_FILE=$TMP_DIR/lock
TMP_PPPD=$TMP_DIR/pppd
TMP_PPTP1=$TMP_DIR/pptp1
TMP_PPTP2=$TMP_DIR/pptp2
TMP_IFACE=$TMP_DIR/iface
TMP_DEVICE=$TMP_DIR/device
TMP_DHS=$TMP_DIR/dhs
TMP_DYNDNS=$TMP_DIR/dyndns

# Modem and network interface addresses. Normally you don't want to change
# this.
MODEM_ADD="10.0.0.138"
ETH_ADD="10.0.0.1"

# You should change this one. For most people, it should be set to eth0. I
# have two network cards and my ADSL modem is connected to the second one, so
# it's eth1 for me.
ADSL_ETH="eth0"

# Not used any more.
# When this script has to kill some processes, sometimes it gest stuck to wait
# something that doesn't happen, so here's the maximal time (in seconds,
# approximatively) that it must wait to consider a process to be inexistant.
KILL_TIMEOUT=10

# If you have a dhs.org account, and want this script to automatically update
# the IP adress for this host, set the DHS variable to 1 and modify the other
# variables tou suit your needs. Otherwise, set the DHS variable to 0.
# NOTE : it works only with dynamic hostnames, such as "foo.dyn.dhs.org", not
# with "foo.dhs.org". NOTE 2 : you'll need lynx to get this working. Check your
# Linux distribution, there should be a package containing it.
DHS=0
DHS_LOGIN=your_dhs_login
DHS_PASS=your_dhs_password
DHS_HOSTNAME=your_dhs_hostname

# WORK IN PROGRESS : same thing, but fot dyndns users. Should work, though.
DYNDNS=0
DYNDNS_LOGIN=your_dyndns_login
DYNDNS_PASS=your_dyndns_password
DYNDNS_HOSTNAME=your_dyndns_hostname

# If you have an Apache server on your machine, set the following variable to 1.
# It will gracefully restart Apache, so that your virtual hosts can work.
# Otherwise, set it to 0. Don't forget to change the second variable to suit
# your needs (if you installed Apache from a package, the path should be right ;
# if you installed from tarball, it must be /usr/local/apache/bin/apachectl).
RESTART_APACHE=0
APACHECTL=/usr/sbin/apachectl

# If Ctrl-C is pressed, we do a clean quit.
function ctrl_c {
	echo "Interrupted by user."
	echo "Warning : you should manually check temp files (in $TMP_DIR)."
	clean_quit 1
}

trap ctrl_c INT


# Creating temp dir.
if [ ! -d $TMP_DIR ] ; then
   mkdir $TMP_DIR
fi

# Checking no other instance is running.
if [ -e $LOCK_FILE ] ; then
   echo "Another instance of this script is running. Aborting."
   exit 1
fi

# We create the temp file.
touch $LOCK_FILE

# A function to cleanly quit.
function clean_quit {
	echo "Cleanly quitting..."
	echo -n "Removing lock file : "
        rm $LOCK_FILE
	echo "done."
        exit $1
}

# Function used to wait for a process to diseapper. See "KILL_TIMEOUT" variable
# above.
function wait_process {
	sleep 1
	COUNT=$[$COUNT + 1]
	if [ $COUNT = $KILL_TIMEOUT ] ; then
	   echo " --> Timeout reached. Process is considered as killed."
	   break
	fi
}


# Okay, here we go. First, the function called to stop the ADSL link.
function adsl_stop {
         # Verifying if the temp files are here. If not, it means that the
	 # current ADSL link might not been started with this script.
	 if [ ! -f $TMP_PPPD -o ! -f $TMP_PPTP1 -o ! -f $TMP_PPTP2 ] ; then
	    echo " --> Can't determine if the current ADSL link was started with this script."
	    echo "Aborting."
	    clean_quit 1
	 fi
	 # Defining PIDs we should kill.
         PPPD_PID="`cat $TMP_PPPD`"
	 PPTP1_PID="`cat $TMP_PPTP1`"
	 PPTP2_PID="`cat $TMP_PPTP2`"
	 # Verifying if the PIDs match the processes we want. If yes, we kill
	 # them. If not, we don't do anything.
	 if [ "`ps ax | grep "$PPTP2_PID".*pptp | grep -v grep`" ] ; then
	    echo " --> Killing pptp GRE-to-PPP gateway..."
	    kill $PPTP2_PID
	    while [ "`ps ax | grep "$PPTP2_PID".*pptp | grep -v grep`" ] ; do
	   	  sleep 1
	    done
	 else
	    echo " --> Warning: pptp GRE-to-PPP gateway not running any more. Skipping..."
	 fi
	 if [ "`ps ax | grep "$PPPD_PID".*pppd | grep -v grep`" ] ; then
	    echo " --> Killing pppd..."
	    kill $PPPD_PID
	    while [ "`ps ax | grep "$PPPD_PID".*pppd | grep -v grep`" ] ; do
	    	  sleep 1
	    done
	 else
	    echo " --> Warning: pppd not running any more. Skipping..."
	 fi
	 if [ "`ps ax | grep "$PPTP1_PID".*pptp | grep -v grep`" ] ; then
	    echo " --> Killing pptp Call Manager..."
	    kill $PPTP1_PID
	    while [ "`ps ax | grep "$PPTP1_PID".*pptp | grep -v grep`" ] ; do
	   	  sleep 1
	    done
	 else
	    echo " --> Warning: pptp Call Manager not running any more. Skipping..."
	 fi
	 # Removing pptp's run files.
	 rm -rf /var/run/pptp
	 # Deconfiguring network interface attached to the ADSL modem.
         ifconfig $ADSL_ETH down
	 # Removing temp files.
	 rm $TMP_PPPD $TMP_PPTP1 $TMP_PPTP2 $TMP_IFACE $TMP_DEVICE
}

# Now the function to start the ADSL link
function adsl_start {
         # First we configure the network interface the ADSL modem is attached
	 # to.
         ifconfig $ADSL_ETH $ETH_ADD
	 # Now we start pptp.
	 pptp $MODEM_ADD
	 # Waiting until it starts pppd...
	 until [ "`$TAIL | grep pppd.*started`" ] ; do
	       sleep 1
	 done
	 echo " --> PPP daemon started..."
	 # Now it's started, we write its PID in a temp file.
	 echo `$TAIL | grep pppd.*started | awk '{print $5}' | sed \
	 "s/pppd\[//" | sed "s/\]://"` > $TMP_PPPD
         # Waiting for pppd to connect...
	 until [ "`$TAIL | grep pppd.*Connect`" ] ; do
	       sleep 1
	 done
	 # Writing interface and device in temp files.
	 IFACE=`$TAIL | grep pppd.*Connect: | awk '{print $7}'`
	 DEV=`$TAIL | grep pppd.*Connect: | awk '{print $9}'`
	 # Saving interface and device in a file.
	 echo $IFACE > $TMP_IFACE
	 echo $DEV > $TMP_DEVICE
	 # We write both pptp processes' PIDs in two other temp files, too.
	 # First, the Call Manager...
	 echo `ps ax | grep pptp.*call.*man.*"$MODEM_ADD" | grep -v grep | awk '{print $1}'` > $TMP_PPTP1
	 # Then, the Gateway...
	 PDEV="`cat $TMP_DEVICE | sed "s/tty/pty/"`"
	 # Waiting for Gateway to start...
	 until [ "`ps ax | grep pptp.*gateway.*"$PDEV" | grep -v grep`" ] ; do
	       sleep 1
	 done
	 echo `ps ax | grep pptp.*gateway.*"$PDEV" | grep -v grep | awk '{print $1}'` > $TMP_PPTP2
	 # Now we watch /var/log/messages, waiting for pppd to connect. If it
	 # tells something bad, we launch the adsl_stop function.
	### 19/04/01 <yeupou@coleumes.org> "login ok" dont works ?
	 while true ; do
	       if [ "`$TAIL | grep pppd.*timeout.*Config\-Requests`" ] ; then
	          echo " --> Timeout sending Config-Requests."
		  adsl_stop
		  echo "Aborting."
		  clean_quit 1
	       elif [ "`$TAIL | grep pppd.*LCP.*terminated.*peer`" ] ; then
	          echo " --> LCP terminated by peer."
		  adsl_stop
		  echo "Aborting."
		  clean_quit 1
	      ### #elif [ "`$TAIL | grep pppd.*Login.ok`" ] ; then
	      ###   echo " --> Login OK."
	      ###break
	       elif [ "`$TAIL | grep pppd.*local.*IP`" ] || [ "`$TAIL | grep pppd.*Login.ok`" ] ; then
	          echo " --> Login OK."
	       break  
	       fi
	 done
	 # Waiting for pppd to get an IP adress
         until [ "`$TAIL | grep pppd.*local.*IP`" ] ; do
	       sleep 1
	 done
	 # Writing some info on standard output.
	 NEWIP=`$TAIL | grep pppd.*local.*IP | awk '{print $9}'`
	 echo " --> Interface $IFACE configured, using device $DEV."
	 echo " --> IP address:  $NEWIP."
	 echo $NEWIP > /etc/ip.info # ajout moa !!
}

# Now, the function to update the dhs.org account, if needed. Quite simple, we
# access the webpage with lynx.
function dhs_update {
         if [ "$DHS" = "1" ] ; then
            echo -n "Updating dhs.org entry : "
            lynx -dump -auth=$DHS_LOGIN:$DHS_PASS "http://63.175.98.30/nic/hosts?domain=dyn.dhs.org&hostname=$DHS_HOSTNAME&hostscmd=edit&hostscmdstage=2&type=4&updatetype=online&ip=$NEWIP" > $TMP_DHS
            echo "done."
         fi
}

# WORK IN PROGRESS : the same function, but for dyndns users. It should work.
function dyndns_update {
	 if [ "$DYNDNS" = "1" ] ; then
	    echo -n "Updating dyndns.org entry : "
	    lynx -dump -auth=$DYNDNS_LOGIN:$DYNDNS_PASS "http://members.dyndns.org/nic/update?hostname=$DYNDNS_HOSTNAME&myip=$NEWIP" > $TMP_DYNDNS
	    echo "done."
	 fi
}

# Last function : the one which restart Apache, if needed.
function restart_apache {
         if [ "$RESTART_APACHE" = "1" ] ; then
	    echo -n "Gracefully restarting Apache : "
	    $APACHECTL graceful > /dev/null
	    echo "done."
	 fi
}

# Now we can start the script. Not much things to do, everything was in the
# functions.
case "$1" in
  start)
  	echo "Starting $DESC: "
        adsl_start
	echo "Done."
	dhs_update
	dyndns_update
	restart_apache
	;;
  stop)
	echo "Stopping $DESC: "
        adsl_stop
	echo "Done."
	;;
  restart)
	echo "Restarting $DESC: "
	adsl_stop
	adsl_start
	echo "Done."
	dhs_update
	dyndns_update
	restart_apache
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart}" >&2
	clean_quit 1
	;;
esac

clean_quit 0
